<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Scegli un&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Applicazioni installate</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Comando personalizzato</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Riga di comando da eseguire:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Nome dell&apos;applicazione:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Questi caratteri speciali possono essere usati nella riga di comando:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: indica un nome file singolo&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: indica diversi nomi file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: indica un URI singolo del file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: indica diversi URI&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Non chiudere il terminale dopo l&apos;esecuzione</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Esegui in un emulatore di terminale</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Ricorda come associazione predefinita per questo tipo di file</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Modifica segnalibri</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Aggiungi elemento</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Rimuovi elemento</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Trascina per riordinare gli elementi</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Esegui file</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>E&amp;segui</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Esegui in un &amp;terminale</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Percorso:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Nome del file:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>Tipo file:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Destinazione:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Elaborazione:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Preparazione...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Avanzamento</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Tempo rimanente:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>File elaborati:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Proprietà file</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Tipo file:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Tipo MIME:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Dimensione file:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Dimensione sul disco:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Ultima modifica:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Destinazione collegamento:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Apri con:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Ultimo accesso:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="281"/>
        <source>Contains:</source>
        <translation>Contiene:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="336"/>
        <source>Device Usage:</source>
        <translation>Utilizzo Device:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="346"/>
        <source>Permissions</source>
        <translation>Permessi</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Ownership</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="385"/>
        <location filename="../file-props.ui" line="450"/>
        <location filename="../file-props.ui" line="564"/>
        <source>Group:</source>
        <translation>Gruppo:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="398"/>
        <location filename="../file-props.ui" line="433"/>
        <location filename="../file-props.ui" line="512"/>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Access Control</source>
        <translation>Controllo degli accessi</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="467"/>
        <location filename="../file-props.ui" line="616"/>
        <source>Other:</source>
        <translation>Altri:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="484"/>
        <source>Make the file executable</source>
        <translation>Rendi il file eseguibile</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="525"/>
        <location filename="../file-props.ui" line="577"/>
        <location filename="../file-props.ui" line="629"/>
        <source>Read</source>
        <translation>Lettura</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="538"/>
        <location filename="../file-props.ui" line="590"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Write</source>
        <translation>Scrittura</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="551"/>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <source>Execute</source>
        <translation>Esecuzione</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="664"/>
        <source>Sticky</source>
        <translation>Sticky Bit</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="671"/>
        <source>SetUID</source>
        <translation>Setta UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="678"/>
        <source>SetGID</source>
        <translation>Setta GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="714"/>
        <source>Advanced Mode</source>
        <translation>Modalità avanzata</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Personalizza</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Seleziona un&apos;applicazione per aprire i file &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Cartella</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>File vuoto</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>La cartella specificata %1 non è valida</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Caricamento in corso...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;nessuna sottocartella&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>Apri in una nuova &amp;scheda</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Apri in una nuova &amp;finestra</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>Apri in un &amp;terminale</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Copia qui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Sposta qui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Crea collegamento qui</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Nuovo segnalibro</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Questo file &apos;%1&apos; sembra un file .desktop.
Cosa vuoi fare?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Questo file di testo &quot;%1&quot; sembra essere uno script eseguibile.
Cosa vuoi fare?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Questo file &quot;%1&quot; è eseguibile. Vuoi eseguirlo?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="109"/>
        <source>Go Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="110"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Sinistra</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Go Forward</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="117"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Destra</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="124"/>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="125"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="142"/>
        <source>Create Folder</source>
        <translation>Crea cartella</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="152"/>
        <source>Icon View</source>
        <translation>Vista icone</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="156"/>
        <source>Thumbnail View</source>
        <translation>Vista miniature</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="160"/>
        <source>Compact View</source>
        <translation>Vista compatta</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Detailed List View</source>
        <translation>Vista dettagliata</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Icon Sizes</source>
        <translation>Dimensione icone</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="174"/>
        <source>Size of big icons:</source>
        <translation>Dimensione delle icone grandi:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="181"/>
        <source>Size of small icons:</source>
        <translation>Dimensione delle icone piccole:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="188"/>
        <source>Size of thumbnails:</source>
        <translation>Dimensione delle anteprime:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="204"/>
        <source>Show Thumbnails</source>
        <translation>Mostra anteprime</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="209"/>
        <source>Show File Tooltips</source>
        <translation type="unfinished">Mostra informazioni sui file</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="220"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="540"/>
        <location filename="../filedialog.cpp" line="935"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="540"/>
        <source>Please select a file</source>
        <translation>Per favore selezionare un file</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="582"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 esiste già.
Sostituirlo?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="905"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Il percorso &quot;%1&quot; non esiste</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="919"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; non è una cartella</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="925"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; non è un file</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1077"/>
        <location filename="../filedialog.cpp" line="1185"/>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1080"/>
        <location filename="../filedialog.cpp" line="1193"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1087"/>
        <source>All Files (*)</source>
        <translation>Tutti file (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Open File</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Save File</source>
        <translation>Salva file</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="84"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="147"/>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="151"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="155"/>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="159"/>
        <location filename="../filemenu.cpp" line="407"/>
        <source>&amp;Move to Trash</source>
        <translation>Cestin&amp;a</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="253"/>
        <source>Trust selected executables</source>
        <translation>Fidati degli eseguibili selezionati</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Trust this executable</source>
        <translation>Fidati del eseguibile</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="342"/>
        <source>Output</source>
        <translation>Risultato</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="407"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="163"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="88"/>
        <source>Open With...</source>
        <translation>Apri con...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="116"/>
        <source>Other Applications</source>
        <translation>Altre applicazioni</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="122"/>
        <source>Create &amp;New</source>
        <translation>Crea &amp;nuovo</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="141"/>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="218"/>
        <source>Extract to...</source>
        <translation>Estrai in...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Extract Here</source>
        <translation>Estrai qui</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Compress</source>
        <translation>Comprimi</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="242"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="312"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="313"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Alcuni file non possono essere spostati nel cestino perché il file system su cui si trovano non supporta questa operazione.
Vuoi invece eliminarli?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="399"/>
        <location filename="../fileoperation.cpp" line="417"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="400"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Vuoi eliminare i file selezionati?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="418"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Vuoi spostare nel cestino i file selezionati?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>Sposta file</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Spostamento dei file seguenti nella cartella di destinazione:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Copia file</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Copia dei file seguenti nella cartella di destinazione:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Cestina file</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Spostamento dei file seguenti nel cestino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Elimina file</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Eliminazione dei file seguenti:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Crea collegamenti simbolici</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Creazione collegamenti simbolici per i seguenti file:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Cambia attributi</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Modifica degli attributi per i seguenti file:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Ripristina file cestinati</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Ripristino dei file seguenti dal cestino:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="146"/>
        <location filename="../fileoperationdialog.cpp" line="152"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>Visualizza il contenuto della cartella</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>Visualizza e modifica il contenuto della cartella</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>Lettura</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>Lettura e scrittura</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>Vietato</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>File di tipi diversi</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <source>Multiple Files</source>
        <translation>File multipli</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="336"/>
        <source>%p% used</source>
        <translation>%p% usato</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="337"/>
        <source>%1 Free of %2</source>
        <translation>%1 Liberi di %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="382"/>
        <source>no file</source>
        <translation>nessun file</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="384"/>
        <source>one file</source>
        <translation>un file</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="386"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln file</numerusform>
            <numerusform>%Ln files</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="420"/>
        <source>Select an icon</source>
        <translation>Seleziona un icona</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="422"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Immagini (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="518"/>
        <source>Apply changes</source>
        <translation>Applica modifiche</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="519"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Vuoi applicare ricorsivamente queste modifiche a tutti i file e a tutte le sottocartelle?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Dovresti aggiungere almeno una cartella in cui cercare.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Seleziona una cartella</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="471"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Una cartella non può essere copiata in se stessa!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="522"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Impossibile creare un collegamento su un filesystem non nativo</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>Crea &amp;nuovo</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>Seleziona t&amp;utto</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>Inverti selezione</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>Ordinamento</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>Mostra nascosti</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Pr&amp;oprietà cartella</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="141"/>
        <source>Output</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="163"/>
        <source>By File Name</source>
        <translation>Per nome file</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="164"/>
        <source>By Modification Time</source>
        <translation>Per data modifica</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="167"/>
        <source>By Deletion Time</source>
        <translation>Per tempo di eliminazione</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="170"/>
        <source>By File Size</source>
        <translation>Per dimensione file</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="171"/>
        <source>By File Type</source>
        <translation>Per tipo file</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="172"/>
        <source>By File Owner</source>
        <translation>Per proprietario file</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="173"/>
        <source>By File Group</source>
        <translation>Per gruppo file</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="179"/>
        <source>Ascending</source>
        <translation>Crescente</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="184"/>
        <source>Descending</source>
        <translation>Decrescente</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="201"/>
        <source>Folder First</source>
        <translation>Prima le cartelle</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="209"/>
        <source>Hidden Last</source>
        <translation>File nascosti ultimi</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="217"/>
        <source>Case Sensitive</source>
        <translation>Distingui MAIUSCOLE/minuscole</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="303"/>
        <source>Location:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>File type:</source>
        <translation>Tipo file:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File size:</source>
        <translation>Dimensione file:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="314"/>
        <source>Last modified:</source>
        <translation>Ultima modifica:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>Last accessed:</source>
        <translation>Ultimo accesso:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Group:</source>
        <translation>Gruppo:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="384"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="387"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="390"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="393"/>
        <source>Modified</source>
        <translation>Modificato</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Deleted</source>
        <translation>Cancellato</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Owner</source>
        <translation>Proprietario</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="373"/>
        <source>Auto-resize columns</source>
        <translation>Larghezza colonne automatica</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="390"/>
        <source>Visible Columns</source>
        <translation>Colonne mostrate</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Connetti</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Modifica percorso</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Copia percorso</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>Risorse</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>Scrivania</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>Applicazioni</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>Dispositivi</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Segnalibri</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="496"/>
        <source>Empty Trash</source>
        <translation>Svuota cestino</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="481"/>
        <source>Open in New Tab</source>
        <translation>Apri in una nuova scheda</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="484"/>
        <source>Open in New Window</source>
        <translation>Apri in una nuova finestra</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="516"/>
        <location filename="../placesview.cpp" line="573"/>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="533"/>
        <source>Move Bookmark Up</source>
        <translation>Sposta segnalibro in su</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="538"/>
        <source>Move Bookmark Down</source>
        <translation>Sposta segnalibro in giù</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="542"/>
        <source>Rename Bookmark</source>
        <translation>Rinomina segnalibro</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="545"/>
        <source>Remove Bookmark</source>
        <translation>Rimuovi segnalibro</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="554"/>
        <location filename="../placesview.cpp" line="587"/>
        <source>Unmount</source>
        <translation>Smonta</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="558"/>
        <source>Mount</source>
        <translation>Monta</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Eject</source>
        <translation>Espelli</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="599"/>
        <source>Show All Entries</source>
        <translation>Mostra tutte le risorse</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tipo: %1
Dimensione: %2
Ultima modifica: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tipo: %1
Ultima modifica: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>S&amp;ovrascrivi</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>Risorse</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>Albero delle cartelle</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Impossibile ripristinare il file &apos;%1&apos;: percorso originale sconosciuto</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Monta</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Connetti in modo &amp;anonimo</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Connetti come &amp;utente:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>&amp;Nome utente:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Password:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Dominio:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Dimentica la password &amp;immediatamente</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>Ricorda password per &amp;questa sessione</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Ricorda per &amp;sempre</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../filelauncher.cpp" line="104"/>
        <location filename="../filepropsdialog.cpp" line="543"/>
        <location filename="../mountoperation.cpp" line="207"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="283"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>Rinomina file</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>Digita un nuovo nome:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>Crea cartella</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>Digita un nuovo nome del file:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>Nuovo file di testo</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>Digita un nuovo nome della cartella:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>Nuova cartella</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>Digita un nome per %1:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>Crea file</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="560"/>
        <source>Custom Icon Error</source>
        <translation>Errore per l&apos;icona personalizzata</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Questo percorso non è montato.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="289"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>File desktop non valido: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="325"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Nessuna applicazione predefinita per eseguire &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="366"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Impossibile impostare cartella di lavoro a &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="123"/>
        <source>Identifier: </source>
        <translation>Identificatore: </translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Conferma sostituzione dei file</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;C&apos;è già un file con lo stesso nome in questa posizione.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Vuoi sostituire il file esistente?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>con il file seguente?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>Nome &amp;file:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Applica questa opzione a tutti i file esistenti</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Cerca file</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Nome/Posizione</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Modelli di nome dei file:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Utilizza un&apos;espressione regolare</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="68"/>
        <source>Places to Search:</source>
        <translation>Risorse in cui cercare:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="81"/>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungi</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="93"/>
        <source>&amp;Remove</source>
        <translation>&amp;Rimuovi</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="129"/>
        <source>Search for hidden files</source>
        <translation>Cerca i file nascosti</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="140"/>
        <source>File Type</source>
        <translation>Tipo di file</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="146"/>
        <source>Only search for files of following types:</source>
        <translation>Cerca solo i file dei tipi seguenti:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="152"/>
        <source>Text files</source>
        <translation>File di testo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="159"/>
        <source>Image files</source>
        <translation>File di immagini</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="166"/>
        <source>Audio files</source>
        <translation>File audio</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="173"/>
        <source>Video files</source>
        <translation>File video</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="180"/>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="187"/>
        <source>Folders</source>
        <translation>Cartelle</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="211"/>
        <source>Content</source>
        <translation>Contenuto</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="217"/>
        <source>File contains:</source>
        <translation>Il file contiene:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Utilizza un&apos;espressione regolare</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>File Size:</source>
        <translation>Dimensione file:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="295"/>
        <source>Larger than:</source>
        <translation>Più grande di:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="309"/>
        <location filename="../filesearch.ui" line="339"/>
        <source>Bytes</source>
        <translation>Byte</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="314"/>
        <location filename="../filesearch.ui" line="344"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="319"/>
        <location filename="../filesearch.ui" line="349"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="324"/>
        <location filename="../filesearch.ui" line="354"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="274"/>
        <source>Smaller than:</source>
        <translation>Più piccolo di:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case sensitive</source>
        <translation>Distingui maiuscolo/minuscolo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="122"/>
        <source>Search in subdirectories</source>
        <translation>Cerca nelle sottocartelle</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="226"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Distingui &amp;maiuscolo/minuscolo</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="370"/>
        <source>Last Modified Time:</source>
        <translation>Ultima modifica:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="378"/>
        <source>Earlier than:</source>
        <translation>Prima del:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Later than:</source>
        <translation>Dopo di:</translation>
    </message>
</context>
</TS>
